def resample(waveform: Tensor,
    orig_freq: int,
    new_freq: int,
    lowpass_filter_width: int=6,
    rolloff: float=0.98999999999999999,
    resampling_method: str="sinc_interpolation",
    beta: Optional[float]=None) -> Tensor:
  _0 = __torch__.torchaudio.functional.functional._get_sinc_resample_kernel
  _1 = __torch__.torchaudio.functional.functional._apply_sinc_resample_kernel
  if torch.gt(orig_freq, 0.):
    _2 = torch.gt(new_freq, 0.)
  else:
    _2 = False
  if _2:
    pass
  else:
    ops.prim.RaiseException("AssertionError: ")
  if torch.eq(orig_freq, new_freq):
    _3 = waveform
  else:
    gcd = torch.gcd(orig_freq, new_freq)
    _4 = _0(orig_freq, new_freq, gcd, lowpass_filter_width, rolloff, resampling_method, beta, ops.prim.device(waveform), ops.prim.dtype(waveform), )
    kernel, width, = _4
    resampled = _1(waveform, orig_freq, new_freq, gcd, kernel, width, )
    _3 = resampled
  return _3
def _get_sinc_resample_kernel(orig_freq: int,
    new_freq: int,
    gcd: int,
    lowpass_filter_width: int,
    rolloff: float,
    resampling_method: str,
    beta: Optional[float],
    device: Device=torch.device("cpu"),
    dtype: Optional[int]=None) -> Tuple[Tensor, int]:
  _5 = "Frequencies must be of integer type to ensure quality resampling computation. To work around this, manually convert both frequencies to integer values that maintain their resampling rate ratio before passing them into the function. Example: To downsample a 44100 hz waveform by a factor of 8, use `orig_freq=8` and `new_freq=1` instead of `orig_freq=44100` and `new_freq=5512.5`. For more information, please refer to https://github.com/pytorch/audio/issues/1487."
  if torch.eq(orig_freq, orig_freq):
    _6 = torch.eq(new_freq, new_freq)
  else:
    _6 = False
  if torch.__not__(_6):
    ops.prim.RaiseException(_5)
  else:
    pass
  _7 = ["sinc_interpolation", "kaiser_window"]
  _8 = torch.__contains__(_7, resampling_method)
  if torch.__not__(_8):
    _9 = torch.format("Invalid resampling method: {}", resampling_method)
    ops.prim.RaiseException(_9)
  else:
    pass
  orig_freq0 = torch.floordiv(orig_freq, gcd)
  new_freq0 = torch.floordiv(new_freq, gcd)
  if torch.gt(lowpass_filter_width, 0):
    pass
  else:
    ops.prim.RaiseException("AssertionError: ")
  kernels = annotate(List[Tensor], [])
  base_freq = ops.prim.min(orig_freq0, new_freq0)
  base_freq0 = torch.mul(base_freq, rolloff)
  _10 = torch.mul(lowpass_filter_width, orig_freq0)
  width = torch.ceil(torch.div(_10, base_freq0))
  if torch.__isnot__(dtype, None):
    dtype1 = unchecked_cast(int, dtype)
    idx_dtype, dtype0 = dtype1, dtype1
  else:
    idx_dtype, dtype0 = 7, dtype
  idx = torch.arange(torch.neg(width), torch.add(width, orig_freq0), dtype=idx_dtype, layout=None, device=device)
  beta0: Optional[float] = beta
  for i in range(new_freq0):
    _11 = torch.div(torch.neg(i), new_freq0)
    _12 = torch.add(torch.div(idx, orig_freq0), _11)
    t = torch.mul(_12, base_freq0)
    t0 = torch.clamp_(t, torch.neg(lowpass_filter_width), lowpass_filter_width)
    _13 = torch.eq(resampling_method, "sinc_interpolation")
    if _13:
      _14 = torch.div(torch.mul(t0, 3.1415926535897931), lowpass_filter_width)
      window0 = torch.pow(torch.cos(torch.div(_14, 2)), 2)
      window, beta1 = window0, beta0
    else:
      if torch.__is__(beta0, None):
        beta2 = 14.769656459379492
      else:
        beta2 = unchecked_cast(float, beta0)
      beta_tensor = torch.tensor(beta2)
      _15 = torch.div(t0, lowpass_filter_width)
      _16 = torch.add(torch.neg(torch.pow(_15, 2)), 1)
      _17 = torch.mul(beta_tensor, torch.sqrt(_16))
      window1 = torch.div(torch.i0(_17), torch.i0(beta_tensor))
      window, beta1 = window1, beta2
    t1 = torch.mul_(t0, 3.1415926535897931)
    kernel = torch.where(torch.eq(t1, 0), torch.to(torch.tensor(1.), t1), torch.div(torch.sin(t1), t1))
    _18 = torch.mul_(kernel, window)
    _19 = torch.append(kernels, kernel)
    beta0 = beta1
  scale = torch.div(base_freq0, orig_freq0)
  _20 = torch.view(torch.stack(kernels), [new_freq0, 1, -1])
  kernels0 = torch.mul_(_20, scale)
  if torch.__is__(dtype0, None):
    kernels1 = torch.to(kernels0, 6)
  else:
    kernels1 = kernels0
  return (kernels1, width)
def _apply_sinc_resample_kernel(waveform: Tensor,
    orig_freq: int,
    new_freq: int,
    gcd: int,
    kernel: Tensor,
    width: int) -> Tensor:
  orig_freq1 = torch.floordiv(orig_freq, gcd)
  new_freq1 = torch.floordiv(new_freq, gcd)
  shape = torch.size(waveform)
  waveform0 = torch.view(waveform, [-1, shape[-1]])
  num_wavs, length, = torch.size(waveform0)
  waveform1 = __torch__.torch.nn.functional._pad(waveform0, [width, torch.add(width, orig_freq1)], "constant", 0., )
  _21 = torch.unsqueeze(torch.slice(waveform1), 1)
  resampled = torch.conv1d(_21, kernel, None, [orig_freq1])
  resampled0 = torch.reshape(torch.transpose(resampled, 1, 2), [num_wavs, -1])
  _22 = torch.div(torch.mul(new_freq1, length), orig_freq1)
  target_length = torch.ceil(_22)
  resampled1 = torch.slice(resampled0, -1, None, target_length)
  _23 = torch.slice(shape, None, -1)
  _24 = torch.slice(torch.size(resampled1), -1)
  resampled2 = torch.view(resampled1, torch.add(_23, _24))
  return resampled2
